pub struct QueueNew {
pub authority: Pubkey,
pub clock: Pubkey,
pub fee: Pubkey,
pub manager: Pubkey,
pub payer: Pubkey,
pub queue: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for QueueNew.
Fields
clock: Pubkeyfee: Pubkeymanager: Pubkeypayer: Pubkeyqueue: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueNewwhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueNewwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueNew
impl ToAccountMetas for QueueNew
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueNew
impl RefUnwindSafe for QueueNew
impl Send for QueueNew
impl Sync for QueueNew
impl Unpin for QueueNew
impl UnwindSafe for QueueNew