pub struct QueueStart {
pub clock: Pubkey,
pub delegate: Pubkey,
pub manager: Pubkey,
pub queue: Pubkey,
}Expand description
Generated client accounts for QueueStart.
Fields
clock: Pubkeydelegate: Pubkeymanager: Pubkeyqueue: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueStartwhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueStartwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueStart
impl ToAccountMetas for QueueStart
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueStart
impl RefUnwindSafe for QueueStart
impl Send for QueueStart
impl Sync for QueueStart
impl Unpin for QueueStart
impl UnwindSafe for QueueStart