pub struct TaskExec {
pub clock: Pubkey,
pub config: Pubkey,
pub delegate: Pubkey,
pub fee: Pubkey,
pub manager: Pubkey,
pub pool: Pubkey,
pub queue: Pubkey,
pub system_program: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for TaskExec.
Fields
clock: Pubkeyconfig: Pubkeydelegate: Pubkeyfee: Pubkeymanager: Pubkeypool: Pubkeyqueue: Pubkeysystem_program: Pubkeytask: PubkeyTrait Implementations
Sourceimpl BorshSerialize for TaskExecwhere
Pubkey: BorshSerialize,
impl BorshSerialize for TaskExecwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for TaskExec
impl ToAccountMetas for TaskExec
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for TaskExec
impl RefUnwindSafe for TaskExec
impl Send for TaskExec
impl Sync for TaskExec
impl Unpin for TaskExec
impl UnwindSafe for TaskExec