pub struct TaskUpdate {
pub authority: Pubkey,
pub manager: Pubkey,
pub queue: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for TaskUpdate.
Fields
manager: Pubkeyqueue: Pubkeytask: PubkeyTrait Implementations
Sourceimpl BorshSerialize for TaskUpdatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for TaskUpdatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for TaskUpdate
impl ToAccountMetas for TaskUpdate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for TaskUpdate
impl RefUnwindSafe for TaskUpdate
impl Send for TaskUpdate
impl Sync for TaskUpdate
impl Unpin for TaskUpdate
impl UnwindSafe for TaskUpdate