pub struct InstructionData {
pub program_id: Pubkey,
pub accounts: Vec<AccountMetaData>,
pub data: Vec<u8>,
}Expand description
InstructionData
Fields
program_id: PubkeyPubkey of the instruction processor that executes this instruction
accounts: Vec<AccountMetaData>Metadata for what accounts should be passed to the instruction processor
data: Vec<u8>Opaque data passed to the instruction processor